# -*- coding: utf-8 -*-

from megrok.menu.component import menuitem, Menu, SubMenuItem

# Provide these directives here as well:
from grokcore.component import name, title, description
from grokcore.viewlet import order



"""
We log as anonymous::

  >>> newInteraction(Participation(Principal('zope.anybody')))

A menu is available as a named utility providing ``IBrowserMenu``.

  >>> from zope.publisher.browser import TestRequest
  >>> from zope.browsermenu.interfaces import IBrowserMenu
  >>> from zope.component import getUtility

  >>> menu = getUtility(IBrowserMenu, 'tabs')
  >>> manfred = Mammoth()
  >>> request = TestRequest()

In order to retrieve the menu items, we need to pass in a context
object and a request.  The menu then determines which menu items are
available for this particular object and the principal that's attached
to the request:

  >>> from pprint import pprint
  >>> pprint(menu.getMenuItems(manfred, request))
  [{'action': 'edit',
    'description': u'',
    'extra': None,
    'icon': None,
    'selected': u'',
    'submenu': None,
    'title': 'Edit'},
   {'action': 'index',
    'description': u'',
    'extra': None,
    'icon': None,
    'selected': u'',
    'submenu': None,
    'title': 'View'}]

  >>> endInteraction()

"""

import megrok.menu
from grokcore.component import Context, name, title, description
from grokcore.security import Permission, require
from grokcore.view import View
from zope.security.management import newInteraction, endInteraction
from zope.security.testing import Principal, Participation


class Mammoth(Context):
    pass


class Tabs(megrok.menu.Menu):
    name('tabs')
    title('Tabs')
    description('')


# You can either refer to the menu class itself:
class Index(View):
    title('View')
    megrok.menu.menuitem(Tabs)

    def render(self):
        return 'index'


# or you can refer to its identifier:
class Edit(View):
    title('Edit')
    megrok.menu.menuitem('tabs')

    def render(self):
        return 'edit'


def test_suite():
    import doctest
    suite = doctest.DocTestSuite()
    suite.layer = megrok.menu.tests.MegrokMenuLayer(megrok.menu.tests)
    return suite




# -*- coding: utf-8 -*-

import zope.component
from zope.component.interfaces import IComponentLookup
from zope.component.testlayer import ZCMLFileLayer
from zope.interface import Interface
from zope.site.folder import rootFolder
from zope.site.site import LocalSiteManager, SiteManagerAdapter


class MegrokMenuLayer(ZCMLFileLayer):

    def setUp(self):
        ZCMLFileLayer.setUp(self)

        # Set up site manager adapter
        zope.component.provideAdapter(
            SiteManagerAdapter, (Interface,), IComponentLookup)

        # Set up site
        site = rootFolder()
        site.setSiteManager(LocalSiteManager(site))
        zope.component.hooks.setSite(site)

        return site

    def tearDown(self):
        ZCMLFileLayer.tearDown(self)
        zope.component.hooks.resetHooks()
        zope.component.hooks.setSite()



from setuptools import setup, find_packages

long_description = (
    open("README.txt").read() + '\n\n' + open("CHANGES.txt").read())

test_requires = []

setup(name='megrok.menu',
      version='0.4.1',
      description="Grok extension to configure browser menus",
      long_description=long_description,
      keywords='',
      author='The Grok community',
      author_email='grok-dev@zope.org',
      url='http://pypi.python.org/pypi/megrok.menu',
      license='ZPL',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['megrok'],
      include_package_data=True,
      zip_safe=False,
      extras_require={'test': [
          'zope.component',
          'zope.interface',
          'zope.principalregistry',
          'zope.security',
          'zope.securitypolicy',
          'zope.site',
          'zope.testing',
          ]},
      install_requires=[
          'grokcore.component',
          'grokcore.security',
          'grokcore.view',
          'grokcore.viewlet',
          'martian',
          'setuptools',
          'zope.browsermenu',
          'zope.configuration',
          'zope.publisher',
      ],
      classifiers=[
          'Programming Language :: Python',
          'Environment :: Web Environment',
          'Framework :: Zope3',
          'License :: OSI Approved :: Zope Public License',
          ],
      )
